empty

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package empty provides empty state messages for TUI components.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Message

type Message struct {
	Title   string
	Body    string
	Hints   []string
	Command string // suggested command to run
}

Message represents an empty state message with optional hints.

func AuthRequired

func AuthRequired() Message

AuthRequired returns an error state for authentication issues.

func FilterNoMatch

func FilterNoMatch() Message

FilterNoMatch returns the empty state when filters yield no results.

func NetworkError

func NetworkError() Message

NetworkError returns an error state for network issues.

func NoAssignments

func NoAssignments() Message

NoAssignments returns the empty state for no assignments.

func NoCheckins

func NoCheckins() Message

NoCheckins returns the empty state for no check-in questions.

func NoColumns

func NoColumns() Message

NoColumns returns the empty state for no card table columns.

func NoComments

func NoComments() Message

NoComments returns the empty state for no comments found.

func NoDockTools

func NoDockTools() Message

NoDockTools returns the empty state for no dock tools.

func NoDocsFiles

func NoDocsFiles() Message

NoDocsFiles returns the empty state for no documents or files.

func NoForwards

func NoForwards() Message

NoForwards returns the empty state for no email forwards.

func NoMessages

func NoMessages() Message

NoMessages returns the empty state for no messages.

func NoPeople

func NoPeople() Message

NoPeople returns the empty state for no people found.

func NoPings

func NoPings() Message

NoPings returns the empty state for no ping threads.

func NoProjects

func NoProjects() Message

NoProjects returns the empty state for no projects found.

func NoRecentItems

func NoRecentItems(itemType string) Message

NoRecentItems returns the empty state for no recent items.

func NoRecordings

func NoRecordings(recordingType string) Message

NoRecordings returns the empty state for no recordings found.

func NoScheduleEntries

func NoScheduleEntries() Message

NoScheduleEntries returns the empty state for no schedule entries.

func NoSearchResults

func NoSearchResults(query string) Message

NoSearchResults returns the empty state for empty search results.

func NoTimeline

func NoTimeline() Message

NoTimeline returns the empty state for no timeline activity.

func NoTodolists

func NoTodolists(projectName string) Message

NoTodolists returns the empty state for no todolists found.

func NoTodos

func NoTodos(context string) Message

NoTodos returns the empty state for no todos found.

Jump to